@@ -71,11 +71,7 @@ mpc_set_size (XfcePanelPlugin * plugin, int size, t_mpc * mpc)
    size /= xfce_panel_plugin_get_nrows (plugin);
    gtk_container_set_border_width (GTK_CONTAINER (mpc->frame), border_width);
    size -= 2 * border_width;
-#if LIBXFCE4PANEL_CHECK_VERSION (4,13,0)
    icon_size = xfce_panel_plugin_get_icon_size(plugin);
-#else
-   icon_size = size / 2;
-#endif
    icon_size -= 2 * border_width;
 
    resize_button (GTK_WIDGET (mpc->next), size, icon_size);
@@ -274,12 +270,11 @@ mpc_create_options (XfcePanelPlugin * plugin, t_mpc* mpc)
 
    xfce_panel_plugin_block_menu (plugin);
 
-   dlg = xfce_titled_dialog_new_with_buttons (_("Mpd Client Plugin"),
-                                              GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(plugin))),
-                                              GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              "gtk-close",
-                                              GTK_RESPONSE_OK,
-                                              NULL);
+   dlg = xfce_titled_dialog_new_with_mixed_buttons (_("Mpd Client Plugin"),
+                                                    GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(plugin))),
+                                                    GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                    "window-close-symbolic", _("_Close"), GTK_RESPONSE_OK,
+                                                    NULL);
    xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Properties"));
 
    gtk_window_set_position   (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
@@ -452,6 +447,13 @@ mpc_repeat_toggled(GtkWidget *widget, t_mpc* mpc)
    mpd_player_set_repeat(mpc->mo, gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)));
 }
 
+static void
+mpc_single_toggled(GtkWidget *widget, t_mpc* mpc)
+{
+   DBG("!");
+   mpd_player_set_single(mpc->mo, gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)));
+}
+
 static void
 mpc_stream_toggled(GtkWidget *widget, t_mpc* mpc)
 {
@@ -604,6 +606,7 @@ enter_cb(GtkWidget *widget, GdkEventCrossing* event, t_mpc* mpc)
 
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->random), mpd_player_get_random(mpc->mo));
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->repeat), mpd_player_get_repeat(mpc->mo));
+   gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->single), mpd_player_get_single(mpc->mo));
    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(mpc->stream), mpc->is_streaming && mpc->streaming_child_pid);
    mpc_update_outputs(mpc);
 
@@ -892,16 +895,20 @@ mpc_create (XfcePanelPlugin * plugin)
    g_signal_connect (G_OBJECT(mpc->stream), "toggled", G_CALLBACK (mpc_stream_toggled), mpc);
    mpc->appl = gtk_menu_item_new_with_label (_("Launch"));
    g_signal_connect (G_OBJECT(mpc->appl), "activate", G_CALLBACK (mpc_launch_client), mpc);
+   mpc->single = gtk_check_menu_item_new_with_label (_("Single"));
+   g_signal_connect (G_OBJECT(mpc->single), "toggled", G_CALLBACK (mpc_single_toggled), mpc);
 
    add_separator_and_label_with_markup(plugin, _("<b><i>Commands</i></b>"));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->random));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->repeat));
+   xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->single));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->stream));
    xfce_panel_plugin_menu_insert_item(plugin,GTK_MENU_ITEM(mpc->appl));
    add_separator_and_label_with_markup(plugin, _("<b><i>Outputs</i></b>"));
    gtk_widget_show (mpc->repeat);
    gtk_widget_show (mpc->random);
    gtk_widget_show (mpc->stream);
+   gtk_widget_show (mpc->single);
    gtk_widget_show (mpc->appl);
    gtk_widget_show_all (mpc->box);
 
@@ -919,7 +926,7 @@ mpc_show_about(XfcePanelPlugin *plugin, t_mpc* mpc)
       "program-name", PACKAGE_NAME,
       "comments", _("A simple panel-plugin client for Music Player Daemon"),
       "website", "https://docs.xfce.org/panel-plugins/xfce4-mpc-plugin",
-      "copyright", "Copyright \302\251 2006-2023 The Xfce development team",
+      "copyright", "Copyright \302\251 2006-2024 The Xfce development team",
       "authors", auth, NULL);
 }
 
@@ -930,7 +937,7 @@ mpc_construct (XfcePanelPlugin * plugin)
 
    DBG("!");
 #ifdef DEBUG
-#if HAVE_LIBMPD
+#ifdef HAVE_LIBMPD
    debug_set_level(10);
 #endif
 #endif
